@@ -11,6 +11,7 @@ import os
 import py
 
 from MoinMoin import user, caching
+from MoinMoin.util import filesys
 
 
 class TestEncodePassword(object):
@@ -38,13 +39,15 @@ class TestLoginWithPassword(object):
 
     def setup_method(self, method):
         # Save original user and cookie
-        self.saved_cookie = self.request.saved_cookie
+        self.saved_cookie = self.request.cookies
         self.saved_user = self.request.user
 
         # Create anon user for the tests
-        self.request.saved_cookie = ''
+        self.request.cookies = {}
         self.request.user = user.User(self.request)
 
+        # Prevent user list caching - we create and delete users too fast for that.
+        filesys.dcdisable()
         self.user = None
 
     def teardown_method(self, method):
@@ -62,7 +65,7 @@ class TestLoginWithPassword(object):
             del self.user
 
         # Restore original user
-        self.request.saved_cookie = self.saved_cookie
+        self.request.cookies = self.saved_cookie
         self.request.user = self.saved_user
 
         # Remove user name to id cache, or next test will fail
@@ -72,6 +75,9 @@ class TestLoginWithPassword(object):
         except:
             pass
 
+        # Prevent user list caching - we create and delete users too fast for that.
+        filesys.dcdisable()
+
     def testAsciiPassword(self):
         """ user: login with ascii password """
         # Create test user
