@@ -12,6 +12,9 @@ DAYS = 30 # we look for spam edits in the last x days
 
 import time
 
+from MoinMoin import log
+logging = log.getLogger(__name__)
+
 from MoinMoin.logfile import editlog
 from MoinMoin.util.dataset import TupleDataset, Column
 from MoinMoin.widget.browser import DataBrowserWidget
@@ -66,7 +69,7 @@ def show_editors(request, pagename, timestamp):
             pg.link_to(request, text=_("Select Author"),
                 querystr={
                     'action': 'Despam',
-                    'editor': editor, # was: url_quote_plus()
+                    'editor': repr(editor),
                 })))
 
     table = DataBrowserWidget(request)
@@ -112,7 +115,7 @@ def show_pages(request, pagename, editor, timestamp):
 </form>
 </p>
 ''' % dict(
-        url="%s/%s" % (request.getScriptname(), wikiutil.quoteWikinameURL(pagename)),
+        url=request.href(pagename),
         ticket=wikiutil.createTicket(request),
         editor=wikiutil.url_quote(editor),
         label=_("Revert all!"),
@@ -156,7 +159,7 @@ def revert_page(request, pagename, editor):
 def revert_pages(request, editor, timestamp):
     _ = request.getText
 
-    editor = wikiutil.url_unquote(editor, want_unicode=False)
+    editor = wikiutil.url_unquote(editor)
     timestamp = int(timestamp * 1000000)
     log = editlog.EditLog(request)
     pages = {}
@@ -173,14 +176,14 @@ def revert_pages(request, editor, timestamp):
             if repr(line.getInterwikiEditorData(request)) == editor:
                 revertpages.append(line.pagename)
 
-    request.write("Pages to revert:<br>%s" % "<br>".join([wikiutil.escape(p) for p in revertpages]))
+    request.write("Pages to revert:<br>%s" % "<br>".join(revertpages))
     for pagename in revertpages:
-        request.write("Begin reverting %s ...<br>" % wikiutil.escape(pagename))
+        request.write("Begin reverting %s ...<br>" % pagename)
         msg = revert_page(request, pagename, editor)
         if msg:
             request.write("<p>%s: %s</p>" % (
                 Page.Page(request, pagename).link_to(request), msg))
-        request.write("Finished reverting %s.<br>" % wikiutil.escape(pagename))
+        request.write("Finished reverting %s.<br>" % pagename)
 
 def execute(pagename, request):
     _ = request.getText
@@ -189,17 +192,17 @@ def execute(pagename, request):
         request.theme.add_msg(_('You are not allowed to use this action.'), "error")
         return Page.Page(request, pagename).send_page()
 
-    editor = request.form.get('editor', [None])[0]
+    editor = request.values.get('editor')
     timestamp = time.time() - DAYS * 24 * 3600
-    ok = request.form.get('ok', [0])[0]
+    ok = request.form.get('ok', 0)
+    logging.debug("editor: %r ok: %r" % (editor, ok))
 
-    request.emit_http_headers()
     request.theme.send_title("Despam", pagename=pagename)
     # Start content (important for RTL support)
     request.write(request.formatter.startContent("content"))
 
-    if (request.request_method == 'POST' and ok and
-        wikiutil.checkTicket(request, request.form.get('ticket', [''])[0])):
+    if (request.method == 'POST' and ok and
+        wikiutil.checkTicket(request, request.form.get('ticket', ''))):
         revert_pages(request, editor, timestamp)
     elif editor:
         show_pages(request, pagename, editor, timestamp)
