@@ -10,7 +10,7 @@
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin import userform, wikiutil
+from MoinMoin import userform
 from MoinMoin.Page import Page
 from MoinMoin.widget import html
 
@@ -33,12 +33,12 @@ class LoginHandler:
         """
         _ = self._
         request = self.request
-        form = html.FORM(method='POST', name='logincontinue')
-        form.append(html.INPUT(type='hidden', name='login', value='login'))
+        form = html.FORM(method='POST', name='logincontinue', action=self.pagename)
+        form.append(html.INPUT(type='hidden', name='action', value='login'))
+        form.append(html.INPUT(type='hidden', name='login', value='1'))
         form.append(html.INPUT(type='hidden', name='stage',
                                value=request._login_multistage_name))
 
-        request.emit_http_headers()
         request.theme.send_title(_("Login"), pagename=self.pagename)
         # Start content (important for RTL support)
         request.write(request.formatter.startContent("content"))
@@ -55,22 +55,21 @@ class LoginHandler:
     def handle(self):
         _ = self._
         request = self.request
-        form = request.form
+        form = request.values
 
         error = None
 
-        islogin = form.get('login', [''])[0]
+        islogin = form.get('login', '')
 
         if islogin: # user pressed login button
             if request._login_multistage:
                 return self.handle_multistage()
             if hasattr(request, '_login_messages'):
                 for msg in request._login_messages:
-                    request.theme.add_msg(wikiutil.escape(msg), "error")
+                    request.theme.add_msg(msg, "error")
             return self.page.send_page()
 
         else: # show login form
-            request.emit_http_headers()
             request.theme.send_title(_("Login"), pagename=self.pagename)
             # Start content (important for RTL support)
             request.write(request.formatter.startContent("content"))
