@@ -16,11 +16,11 @@ def execute(pagename, request):
 
     if not request.user.isSuperUser():
         request.theme.add_msg(_("Only superuser is allowed to use this action."), "error")
-    elif (request.request_method == 'POST' and
-          wikiutil.checkTicket(request, form.get('ticket', [''])[0])):
-        user_name = form.get('name', [''])[0]
-        key = form.get('key', [''])[0]
-        val = form.get('val', [''])[0]
+    elif (request.method == 'POST' and
+          wikiutil.checkTicket(request, form.get('ticket', ''))):
+        user_name = form.get('name', '')
+        key = form.get('key', '')
+        val = form.get('val', '')
         if key in cfg.user_checkbox_fields:
             val = int(val)
         uid = user.getUserId(request, user_name)
@@ -28,7 +28,7 @@ def execute(pagename, request):
         oldval = getattr(theuser, key)
         setattr(theuser, key, val)
         theuser.save()
-        request.theme.add_msg('%s.%s: %s -> %s' % tuple([wikiutil.escape(s) for s in [user_name, key, oldval, val]]), "info")
+        request.theme.add_msg('%s.%s: %s -> %s' % (user_name, key, oldval, val), "info")
 
     Page(request, pagename).send_page()
 
