@@ -32,6 +32,7 @@ class Parser:
         Methods named like _*_repl() are responsible to handle the named regex patterns.
     """
 
+    extensions = ['.moin']
     # allow caching
     caching = 1
     Dependencies = Dependencies
@@ -42,7 +43,7 @@ class Parser:
  Links:: <<Verbatim(JoinCapitalizedWords)>>; <<Verbatim([[target|linktext]])>>.
  Tables:: || cell text |||| cell text spanning 2 columns ||;    no trailing white space allowed after tables or titles.
 
-(!) For more help, see HelpOnEditing or SyntaxReference.
+(!) For more help, see HelpOnEditing or HelpOnMoinWikiSyntax.
 """)
 
     # some common strings
@@ -692,7 +693,7 @@ class Parser:
     def _transclude_repl(self, word, groups):
         """Handles transcluding content, usually embedding images."""
         target = groups.get('transclude_target', '')
-        target = wikiutil.url_unquote(target, want_unicode=True)
+        target = wikiutil.url_unquote(target)
         desc = groups.get('transclude_desc', '') or ''
         params = groups.get('transclude_params', u'') or u''
         acceptable_attrs_img = ['class', 'title', 'longdesc', 'width', 'height', 'align', ] # no style because of JS
@@ -723,7 +724,7 @@ class Parser:
 
             elif m.group('attach_scheme'):
                 scheme = m.group('attach_scheme')
-                url = wikiutil.url_unquote(m.group('attach_addr'), want_unicode=True)
+                url = wikiutil.url_unquote(m.group('attach_addr'))
                 if scheme == 'attachment':
                     mt = wikiutil.MimeType(filename=url)
                     if mt.major == 'text':
@@ -742,7 +743,7 @@ class Parser:
                         current_pagename = self.formatter.page.page_name
                         pagename, filename = AttachFile.absoluteName(url, current_pagename)
                         if AttachFile.exists(self.request, pagename, filename):
-                            href = AttachFile.getAttachUrl(pagename, filename, self.request, escaped=0)
+                            href = AttachFile.getAttachUrl(pagename, filename, self.request)
                             tag_attrs, query_args = self._get_params(params,
                                                                      tag_attrs={'title': desc, },
                                                                      acceptable_attrs=acceptable_attrs_object)
@@ -766,6 +767,7 @@ class Parser:
                             pagename = self.formatter.page.page_name
                             return m.execute('EmbedObject', u'target=%s' % url)
                 elif scheme == 'drawing':
+                    url = wikiutil.drawing2fname(url)
                     desc = self._transclude_description(desc, url)
                     if desc:
                         tag_attrs= {'alt': desc, 'title': desc, }
@@ -851,7 +853,7 @@ class Parser:
         target = groups.get('link_target', '')
         desc = groups.get('link_desc', '') or ''
         params = groups.get('link_params', u'') or u''
-        acceptable_attrs = ['class', 'title', 'target', 'accesskey', ] # no style because of JS
+        acceptable_attrs = ['class', 'title', 'target', 'accesskey', 'rel', ] # no style because of JS
         mt = self.link_target_re.match(target)
         if mt:
             if mt.group('page_name'):
@@ -895,15 +897,16 @@ class Parser:
 
             elif mt.group('attach_scheme'):
                 scheme = mt.group('attach_scheme')
-                url = wikiutil.url_unquote(mt.group('attach_addr'), want_unicode=True)
+                url = wikiutil.url_unquote(mt.group('attach_addr'))
                 tag_attrs, query_args = self._get_params(params,
                                                          tag_attrs={'title': desc, },
                                                          acceptable_attrs=acceptable_attrs)
-                if scheme == 'attachment':
+                if scheme == 'attachment': # ZZZ
                     return (self.formatter.attachment_link(1, url, querystr=query_args, **tag_attrs) +
                             self._link_description(desc, target, url) +
                             self.formatter.attachment_link(0))
                 elif scheme == 'drawing':
+                    url = wikiutil.drawing2fname(url)
                     return self.formatter.attachment_drawing(url, desc, alt=desc, **tag_attrs)
             else:
                 if desc:
@@ -1433,6 +1436,10 @@ class Parser:
         rawtext = self.raw.expandtabs()
 
         # go through the lines
+
+        for lineno in range(1, self.start_line + 1):
+            self.request.write(self.formatter.line_anchordef(lineno))
+
         self.lineno = self.start_line
         self.lines = self.eol_re.split(rawtext)
         self.line_is_empty = 0
